@@ -26,7 +26,7 @@ fn one_point_grid() {
     assert_eq!(g.iter().next(), None);
     g.fill();
     assert_eq!(g.iter().collect_vec(), vec![(0, 0)]);
-    assert_eq!(g.neighbours(&(0, 0)), vec![]);
+    assert_eq!(g.neighbours((0, 0)), vec![]);
     assert_eq!(g.edges().next(), None);
 }
 
@@ -36,11 +36,11 @@ fn diagonal_mode() {
     assert_eq!(g.iter().count(), 0);
     g.fill();
     assert_eq!(g.iter().count(), 9);
-    let mut ns = g.neighbours(&(1, 1));
+    let mut ns = g.neighbours((1, 1));
     ns.sort_unstable();
     assert_eq!(ns, vec![(0, 1), (1, 0), (1, 2), (2, 1)]);
     g.enable_diagonal_mode();
-    let mut ns = g.neighbours(&(1, 1));
+    let mut ns = g.neighbours((1, 1));
     ns.sort_unstable();
     assert_eq!(
         ns,
@@ -56,7 +56,7 @@ fn diagonal_mode() {
         ]
     );
     g.disable_diagonal_mode();
-    let mut ns = g.neighbours(&(1, 1));
+    let mut ns = g.neighbours((1, 1));
     ns.sort_unstable();
     assert_eq!(ns, vec![(0, 1), (1, 0), (1, 2), (2, 1)]);
 }
@@ -81,15 +81,15 @@ fn resize() {
     assert_eq!(g.vertices_len(), 4);
     assert!(!g.resize(10, 10));
     assert_eq!(g.vertices_len(), 4);
-    let mut ns = g.neighbours(&(1, 1));
+    let mut ns = g.neighbours((1, 1));
     ns.sort_unstable();
     assert_eq!(ns, vec![(0, 1), (1, 0)]);
     for _ in 0..2 {
-        let ns = g.neighbours(&(1, 1));
+        let ns = g.neighbours((1, 1));
         for n in iproduct!(0..g.width, 0..g.height) {
             let present = ns.contains(&n);
-            assert_eq!(g.has_edge(&(1, 1), &n), present);
-            assert_eq!(g.has_edge(&n, &(1, 1)), present);
+            assert_eq!(g.has_edge((1, 1), n), present);
+            assert_eq!(g.has_edge(n, (1, 1)), present);
         }
         g.enable_diagonal_mode();
     }
@@ -112,15 +112,15 @@ fn add_remove() {
     let mut g = Grid::new(3, 3);
     g.fill();
     for _ in 0..2 {
-        assert!(g.has_vertex(&(1, 1)));
-        assert!(g.remove_vertex(&(1, 1)));
-        assert!(!g.has_vertex(&(1, 1)));
-        assert!(!g.remove_vertex(&(1, 1)));
-        assert!(!g.has_vertex(&(1, 1)));
+        assert!(g.has_vertex((1, 1)));
+        assert!(g.remove_vertex((1, 1)));
+        assert!(!g.has_vertex((1, 1)));
+        assert!(!g.remove_vertex((1, 1)));
+        assert!(!g.has_vertex((1, 1)));
         assert!(g.add_vertex((1, 1)));
-        assert!(g.has_vertex(&(1, 1)));
+        assert!(g.has_vertex((1, 1)));
         assert!(!g.add_vertex((1, 1)));
-        assert!(g.has_vertex(&(1, 1)));
+        assert!(g.has_vertex((1, 1)));
         g.resize(1000, 1000);
     }
 }
@@ -164,7 +164,7 @@ fn iterators() {
             if rng.gen_bool(0.5) {
                 g.add_vertex((x, y));
             } else {
-                g.remove_vertex(&(x, y));
+                g.remove_vertex((x, y));
             }
         }
         if rng.gen_bool(0.2) {
@@ -193,14 +193,14 @@ fn is_inside() {
     let g = Grid::new(2, 4);
     for x in 0..2 {
         for y in 0..4 {
-            assert!(g.is_inside(&(x, y)));
+            assert!(g.is_inside((x, y)));
         }
     }
     for x in 0..2 {
-        assert!(!g.is_inside(&(x, 4)));
+        assert!(!g.is_inside((x, 4)));
     }
     for y in 0..4 {
-        assert!(!g.is_inside(&(2, y)));
+        assert!(!g.is_inside((2, y)));
     }
 }
 
@@ -213,23 +213,23 @@ fn add_outside_vertex() {
 #[test]
 fn remove_outside_vertex() {
     let mut g = Grid::new(10, 10);
-    assert!(!g.remove_vertex(&(10, 10)));
+    assert!(!g.remove_vertex((10, 10)));
 }
 
 #[test]
 fn test_outside_vertex() {
     let mut g = Grid::new(10, 10);
-    assert!(!g.has_vertex(&(10, 10)));
+    assert!(!g.has_vertex((10, 10)));
     g.fill();
-    assert!(!g.has_vertex(&(10, 10)));
+    assert!(!g.has_vertex((10, 10)));
 }
 
 #[test]
 fn neighbours_outside_vertex() {
     let mut g = Grid::new(10, 10);
-    assert_eq!(g.neighbours(&(10, 10)), vec![]);
+    assert_eq!(g.neighbours((10, 10)), vec![]);
     g.fill();
-    assert_eq!(g.neighbours(&(10, 10)), vec![]);
+    assert_eq!(g.neighbours((10, 10)), vec![]);
 }
 
 #[test]
@@ -250,12 +250,12 @@ fn add_borders() {
     assert_eq!(g.add_borders(), 10);
     assert_eq!(g.vertices_len(), 10);
     for x in 0..3 {
-        assert!(g.has_vertex(&(x, 0)));
-        assert!(g.has_vertex(&(x, 3)));
+        assert!(g.has_vertex((x, 0)));
+        assert!(g.has_vertex((x, 3)));
     }
     for y in 0..4 {
-        assert!(g.has_vertex(&(0, y)));
-        assert!(g.has_vertex(&(2, y)));
+        assert!(g.has_vertex((0, y)));
+        assert!(g.has_vertex((2, y)));
     }
     assert_eq!(g.add_borders(), 0);
 }
@@ -279,12 +279,12 @@ fn remove_borders() {
     assert_eq!(g.remove_borders(), 10);
     assert_eq!(g.vertices_len(), 2);
     for x in 0..3 {
-        assert!(!g.has_vertex(&(x, 0)));
-        assert!(!g.has_vertex(&(x, 3)));
+        assert!(!g.has_vertex((x, 0)));
+        assert!(!g.has_vertex((x, 3)));
     }
     for y in 0..4 {
-        assert!(!g.has_vertex(&(0, y)));
-        assert!(!g.has_vertex(&(2, y)));
+        assert!(!g.has_vertex((0, y)));
+        assert!(!g.has_vertex((2, y)));
     }
     assert_eq!(g.remove_borders(), 0);
 }
@@ -338,7 +338,7 @@ fn edges() {
     );
     let mut g = Grid::new(3, 3);
     g.fill();
-    g.remove_vertex(&(1, 1));
+    g.remove_vertex((1, 1));
     let mut edges = g.edges().collect::<Vec<_>>();
     edges.sort_unstable();
     assert_eq!(
@@ -359,13 +359,13 @@ fn edges() {
 #[test]
 fn distance() {
     let mut g = Grid::new(10, 10);
-    assert_eq!(g.distance(&(2, 3), &(7, 5)), 7);
-    assert_eq!(g.distance(&(7, 5), &(2, 3)), 7);
-    assert_eq!(g.distance(&(3, 2), &(5, 7)), 7);
-    assert_eq!(g.distance(&(5, 7), &(3, 2)), 7);
+    assert_eq!(g.distance((2, 3), (7, 5)), 7);
+    assert_eq!(g.distance((7, 5), (2, 3)), 7);
+    assert_eq!(g.distance((3, 2), (5, 7)), 7);
+    assert_eq!(g.distance((5, 7), (3, 2)), 7);
     g.enable_diagonal_mode();
-    assert_eq!(g.distance(&(2, 3), &(7, 5)), 5);
-    assert_eq!(g.distance(&(7, 5), &(2, 3)), 5);
-    assert_eq!(g.distance(&(3, 2), &(5, 7)), 5);
-    assert_eq!(g.distance(&(5, 7), &(3, 2)), 5);
+    assert_eq!(g.distance((2, 3), (7, 5)), 5);
+    assert_eq!(g.distance((7, 5), (2, 3)), 5);
+    assert_eq!(g.distance((3, 2), (5, 7)), 5);
+    assert_eq!(g.distance((5, 7), (3, 2)), 5);
 }
