@@ -40,6 +40,12 @@ fn from_vec_error() {
     assert!(Matrix::from_vec(2, 3, vec![20, 30, 40, 50, 60]).is_err());
 }
 
+#[test]
+#[should_panic]
+fn new_empty_row_panic() {
+    let _ = Matrix::new(1, 0, 42);
+}
+
 #[test]
 fn to_vec() {
     let mut m = Matrix::new(2, 2, 0usize);
@@ -154,6 +160,24 @@ fn non_square_rotate() {
     assert_eq!(m0.rotated_ccw(4), m0);
 }
 
+#[test]
+#[should_panic]
+fn no_rows_rotated_cw_panic() {
+    let _ = Matrix::<u32>::new_empty(10).rotated_cw(1);
+}
+
+#[test]
+#[should_panic]
+fn no_rows_rotated_ccw_panic() {
+    let _ = Matrix::<u32>::new_empty(10).rotated_ccw(1);
+}
+
+#[test]
+fn no_rows_rotated_twice() {
+    let _ = Matrix::<u32>::new_empty(10).rotated_cw(2);
+    let _ = Matrix::<u32>::new_empty(10).rotated_ccw(2);
+}
+
 #[test]
 fn flip() {
     let m1 = Matrix::square_from_vec(vec![0, 1, 2, 3]).unwrap();
@@ -176,6 +200,12 @@ fn transpose() {
     assert_eq!(m2.transposed(), m1);
 }
 
+#[test]
+#[should_panic]
+fn no_rows_transposed_panic() {
+    let _ = Matrix::<u32>::new_empty(10).transposed();
+}
+
 fn sum(slice: &[usize]) -> usize {
     slice.iter().sum::<usize>()
 }
@@ -262,10 +292,15 @@ fn empty_extend() {
 }
 
 #[test]
-#[should_panic]
-fn extend_bad_size_panic() {
+fn extend_bad_size_error() {
     let mut m = Matrix::new_empty(3);
-    m.extend(&[0, 1]).unwrap();
+    assert!(m.extend(&[0, 1]).is_err());
+}
+
+#[test]
+fn extend_empty_row_error() {
+    let mut m: Matrix<u32> = matrix![];
+    assert!(m.extend(&[]).is_err());
 }
 
 #[test]
@@ -334,6 +369,33 @@ fn neighbours() {
     }
 }
 
+#[test]
+fn empty_neighbours() {
+    let m: Matrix<u32> = matrix![];
+    assert_eq!(m.neighbours((0, 0), false).collect::<Vec<_>>(), vec![]);
+    assert_eq!(m.neighbours((0, 0), true).collect::<Vec<_>>(), vec![]);
+    let m = Matrix::new(10, 10, 42);
+    assert_eq!(m.neighbours((10, 10), false).collect::<Vec<_>>(), vec![]);
+    assert_eq!(m.neighbours((10, 10), true).collect::<Vec<_>>(), vec![]);
+}
+
+#[test]
+fn reachable() {
+    let m = matrix![[0, 1, 2], [3, 4, 5], [6, 7, 8]];
+
+    let indices = m.reachable((1, 0), false, |n| m[n] % 4 != 0);
+    assert_eq!(
+        indices.into_iter().collect::<Vec<_>>(),
+        vec![(1, 0), (2, 0), (2, 1)]
+    );
+
+    let indices = m.reachable((1, 0), true, |n| m[n] % 4 != 0);
+    assert_eq!(
+        indices.into_iter().collect::<Vec<_>>(),
+        vec![(0, 1), (0, 2), (1, 0), (1, 2), (2, 0), (2, 1)]
+    );
+}
+
 #[test]
 fn from_rows() {
     let m = Matrix::from_rows((1..3).map(|n| (1..5).map(move |x| x * n))).unwrap();
